.. _supported-versions:

Supported versions
==================

``django-guardian`` supports Python 3.8+ and Django 3.2+.

Rules
-----

* We support Python 3.8+.
* We support Django 3.2+. This is due to many simplifications in code we could
  do.
